# Summary

* [Overview](overview.md)
* [Navigating CORD](navigate.md)
* [Quick Start](quickstart/quickstart.md)
    * [SEBA Quick Start](quickstart/seba_quickstart.md)
    * [ExampleService Quick Start](quickstart/example_service_quickstart.md)
        * [MacOS](quickstart/macos.md)
        * [Linux](quickstart/linux.md)

## Guides

* [Installation Guide](README.md)
    * [Prerequisites](prereqs/README.md)
        * [Hardware Requirements](prereqs/hardware.md)
        * [Connectivity Requirements](prereqs/networking.md)
        * [Software Requirements](prereqs/software.md)
            * [Kubernetes](prereqs/kubernetes.md)
                * [Single Node](prereqs/k8s-single-node.md)
                * [Multi-Node](prereqs/k8s-multi-node.md)
            * [Helm](prereqs/helm.md)
    * [Fabric Software Setup](installation/fabric-setup.md)
    * [Install Platform](installation/platform.md)
    * [Install Profile](installation/profiles.md)
    * [Offline Install](installation/offline-install.md)
* [Operations Guide](operating_cord/operating_cord.md)
    * [General Info](operating_cord/general.md)
        * [GUI](operating_cord/gui.md)
            * [Configuring the Service Graph](xos-gui/developer/service_graph.md)
        * [cordctl](cordctl/README.md)
        * [XOSSH](xos/dev/xossh.md)
    * [APIs](operating_cord/api.md)
        * [gRPC API](xos/dev/grpc_api.md)
        * [REST API](operating_cord/rest_apis.md)
        * [TOSCA](xos-tosca/README.md)
    * [Monitoring and Logging](operating_cord/diag.md)
        * [Prometheus](operating_cord/prometheus.md)
        * [ELK Stack](operating_cord/elk_stack.md)
* [Development Guide](developer/developer.md)
    * [Getting the Source Code](developer/getting_the_code.md)
    * [Contribute to the documentation](developer/contribute_to_the_docs.md)
    * [Testing and releasing software](developer/test_release_software.md)
    * [Modeling Services](developer/xos-intro.md)
    * Developer Workflows
        * [Service Migrations](xos/dev/xosmigrate.md)
        * [Local Development](developer/workflows/local.md)
        * [SiaB Development](developer/workflows/siab.md)
            * [ONOS Apps Development](developer/workflows/onos-apps.md)
    * [GUI Development](xos-gui/developer/README.md)
        * [Quickstart](xos-gui/developer/quickstart.md)
        * [GUI Extensions](xos-gui/developer/gui_extensions.md)
        * [GUI Internals](xos-gui/architecture/README.md)
            * [Module Strucure](xos-gui/architecture/gui-modules.md)
            * [Data Sources](xos-gui/architecture/data-sources.md)
        * [Tests](xos-gui/developer/tests.md)
    * [Unit Tests](xos/dev/unittest.md)
    * [Versions and Releases](developer/versioning.md)
* [Testing Guide](cord-tester/README.md)
    * [Test Setup](cord-tester/qa_testsetup.md)
    * [Test Environment](cord-tester/qa_testenv.md)
    * [System Tests](cord-tester/validate_pods.md)

## References

* [Profile Reference](profiles/intro.md)
    * [SEBA](profiles/seba/README.md)
        * [Release Notes](profiles/seba/release-notes.md)
        * Install
            * [Install SEBA Charts](profiles/seba/install.md)
            * Workflows
                * [Install AT&T workflow](profiles/seba/workflows/att-install.md)
            * [EdgeCore OLT Setup (OpenOLT driver)](openolt/README.md)
            * [SEBA-in-a-Box Overview](profiles/seba/siab-overview.md)
                * [SEBA-in-a-Box](profiles/seba/siab.md)
                * [SEBA-in-a-Box with Fabric Switch](profiles/seba/siab-with-fabric-switch.md)
            * [Scale testing with BBSim](profiles/seba/bbsim.md)
            * Other Setups
                * [Configuring a lab setup](profiles/seba/lab-setup.md)
                * [Attach Container to a NIC](profiles/seba/veth_intf.md)
        * Configure
            * [Configure the Pod](profiles/seba/configuration.md)
            * [Configure ONU Whitelist](profiles/seba/configure/onu-whitelist.md)
            * [Configure Tech Profiles](profiles/seba/configure/tech-profile.md)
            * [Provision Subscribers](profiles/seba/configure/subscriber.md)
            * [Provision OLTs](profiles/seba/configure/olt.md)
        * Operate
            * AT&T Workflow
                * [AttWorkflowDriver service instances](profiles/seba/operate/att-si.md)
                * [Workflow description](profiles/seba/operate/att-workflow-description.md)
            * [Working with Tech Profiles](profiles/seba/operate/tp-ops.md)
            * [Working with Bandwidth Profiles](profiles/seba/operate/bp-ops.md)
            * [Disable/Enable an ONU](profiles/seba/operate/onu-ops.md)
            * [Edit a Whitelist entry](profiles/seba/operate/whitelist-ops.md)
            * [Delete an OLT](profiles/seba/operate/olt-ops.md)
            * [Runtime configuration](profiles/seba/operate/config-ops.md)
            * [Add a cross-connect in the AGG switch](profiles/seba/operate/agg-ops.md)
            * [Command-line Management Tools](profiles/seba/operate/cordctl.md)
            * [Try a new version of *](profiles/seba/operate/k8s-helm-ops.md)
        * [Known Issues](profiles/seba/known-issues.md)
        * Troubleshoot (FAQ)
            * [No ONUs discovered](profiles/seba/troubleshoot/no-onus.md)
            * [No AttWorkflowDriver service instances](profiles/seba/troubleshoot/no-att-si.md)
            * [I can't authenticate](profiles/seba/troubleshoot/no-aaa.md)
            * [DHCP is not working](profiles/seba/troubleshoot/no-dhcp.md)
            * [I can't ping](profiles/seba/troubleshoot/no-ping.md)
    * [M-CORD](profiles/mcord/README.md)
        * Install
            * [Install M-CORD Charts](profiles/mcord/install.md)
            * [EnodeB Setup](profiles/mcord/enodeb-setup.md)
        * [Configure](profiles/mcord/configuration.md)
* [Service Reference](operating_cord/services.md)
    * [Fabric](fabric/README.md)
    * [Fabric Crossconnect](fabric-crossconnect/README.md)
    * [ONOS](onos-service/README.md)
    * [RCORD](rcord/README.md)
    * [vOLT](olt-service/README.md)
    * [vRouter](vrouter/README.md)
    * [AT&T Workflow Driver](att-workflow-driver/README.md)
    * [Kubernetes](kubernetes-service/kubernetes-service.md)
    * [SimpleExampleService](simpleexampleservice/simple-example-service.md)
* [Helm Reference](charts/helm.md)
    * [Base Kubernetes](charts/base-kubernetes.md)
    * [BBSim](charts/bbsim.md)
    * [Kafka](charts/kafka.md)
    * [Logging and Monitoring](charts/logging-monitoring.md)
    * [Mininet](charts/mininet.md)
    * [ONOS](charts/onos.md)
    * [Persistent Storage](charts/storage.md)
    * [PONNET](charts/ponnet.md)
    * [PONSIM v2](charts/ponsimv2.md)
    * [PONSIM Pod](charts/ponsim-pod.md)
    * [SEBA services](charts/seba-services.md)
    * [VOLTHA](charts/voltha.md)
    * [XOS-CORE](charts/xos-core.md)
    * [XOSSH](charts/xossh.md)
